OiRA

Help

1. Préparation
2. Impliquer
3. Identification + Estimation
4. Plan d'action
5. Rapport
6. Avancement 37%

# Statut de Commercial guarding, Leicester

## Informations générales

Outil utilisé

  Commercial guarding, Leicester

Commencé le

  5 August 2017 by angela.baumeister@company.com

Sauvegardé

  7 June 2018 by hans.mittelmaier@company.com

## Questions ayant reçu une réponse par module

Commercial manned guarding - Abby Road

  1 question answered without a risk

  3 answers indicated a risk and have at least one measure defined in the action plan

  2 answers indicated a risk without any measure defined in the action plan

  2 questions were postponed

  2 questions aren't answered yet

  - 1 OK
  - 3
  - 2 Attention
  - 2 A faire
  - 2 Sans réponse

  #### Risque hautement prioritaire

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis
Mobile partrolling/intervention after alarm

  7 Sans réponse

  1

  1 Attention

  1 A faire

  - 7 Sans réponse
  - 1
  - 1 Attention
  - 1 A faire

  #### High priority risks

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis

Scroll to top
Back

## status.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More